@@ -15,4 +15,4 @@ chatbot.dataset("sample.csv","input","label",model)
 while True:
  prompt = input("You: ")
  #run model and parse input
- print("Bot: ",chatbot.model_run("spimx",prompt,model))
\ No newline at end of file
+ print("Bot: ",chatbot.model_load("spim",prompt,model))
\ No newline at end of file
